Learn R Programming

matpow (version 0.1.2)

dup: Deep-Copy

Description

Functions to perform deep copies of matrices.

Usage

dup.vanilla(mat) 
   dup.bigmemory(mat)

Arguments

mat

matrix to be copied.

Value

The matrix copy.

Details

One of the arugments to matpow is dup, a function to do deep copying of the type of matrix being used. The user may supply a custom one, or use either dup.vanilla or dup.bigmemory.