Description
Functions to perform deep copies of
matrices.
Usage
dup.vanilla(mat)
dup.bigmemory(mat)
Details
One of the arugments to matpow is dup, a
function to do deep copying of the type of matrix being used. The user
may supply a custom one, or use either dup.vanilla or
dup.bigmemory.